highfivve_advertising library
Classes
- AdEvent
- AdSlot
- AdSlotSize
- AdUnit
- AdUnitPath
- AdvertisingFlutterApi
- AdvertisingHostApi
- HighfivveAdManager
- A singleton manager for handling Highfivve advertising SDK operations.
- HighfivveBannerAdView
- A widget that displays a native Highfivve banner advertisement.
- HighfivveBannerAdWidget
- A widget that displays a dynamic Highfivve banner advertisement.
- HighfivveInterstitialAd
- A controller for loading and displaying Highfivve interstitial advertisements.
Enums
Functions
-
wrapResponse(
{Object? result, PlatformException? error, bool empty = false}) → List< Object?>